// src/cli.ts
import path from "path";
import yargs from "yargs";
import {PurgeIcons} from "@purge-icons/core";
import fs from "fs-extra";
yargs.scriptName("purge-icons").usage("$0 [args]").command("*", "List dependencies versions usage across packages", (args) => {
  return args.option("output", {
    alias: "o",
    type: "string",
    describe: "path for output file, will output to stdout when this option is not provied"
  }).option("content", {
    alias: "c",
    type: "string",
    array: true,
    required: true,
    describe: "glob for matching source files, sepereted by comma"
  }).option("included", {
    alias: "i",
    type: "string",
    array: true,
    describe: "whitelist for icons to be included"
  }).option("format", {
    alias: "f",
    type: "string",
    describe: "output file format",
    choices: [
      "js",
      "mjs",
      "cjs",
      "ts",
      "json"
    ]
  });
}, async (args) => {
  var _a, _b, _c;
  const format = args.format || ((_c = (_b = (_a = path.parse(args.output || "")) == null ? void 0 : _a.ext) == null ? void 0 : _b.slice(1)) == null ? void 0 : _c.toLowerCase()) || "mjs";
  const code = await PurgeIcons({
    content: args.content.flatMap((i) => i.split(",")).map((i) => i.trim()).filter(Boolean),
    format,
    included: args.included
  });
  if (args.output) {
    const filepath = path.resolve(args.output);
    await fs.ensureDir(path.dirname(filepath));
    await fs.writeFile(filepath, code, "utf-8");
  } else {
    console.log(code);
  }
}).showHelpOnFail(false).help().argv;
